@@ -4,10 +4,10 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(trim_blank_lines);
+our @EXPORT_OK = qw(trim_blank_lines ellipsis);
 
 sub trim_blank_lines {
     local $_ = shift;
@@ -17,6 +17,18 @@ sub trim_blank_lines {
     $_;
 }
 
+sub ellipsis {
+    my ($str, $maxlen, $ellipsis) = @_;
+    $maxlen   //= 80;
+    $ellipsis //= "...";
+
+    if (length($str) <= $maxlen) {
+        return $str;
+    } else {
+        return substr($str, 0, $maxlen-length($ellipsis)) . $ellipsis;
+    }
+}
+
 1;
 # ABSTRACT: String utilities
 
@@ -30,7 +42,7 @@ SHARYANTO::String::Util - String utilities
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 FUNCTIONS
 
@@ -39,6 +51,12 @@ version 0.18
 Trim blank lines at the beginning and the end. Won't trim blank lines in the
 middle. Blank lines include lines with only whitespaces in them.
 
+=head2 ellipsis($str[, $maxlen, $ellipsis]) => STR
+
+Return $str unmodified if $str's length is less than $maxlen (default 80).
+Otherwise cut $str to ($maxlen - length($ellipsis)) and append $ellipsis
+(default '...') at the end.
+
 =head1 SEE ALSO
 
 L<SHARYANTO::Utils>
